@@ -1,25 +1,35 @@
 from __future__ import annotations
 
 import re
-from dataclasses import dataclass, asdict
+from dataclasses import asdict, dataclass
 from enum import Enum
 from typing import Any, Optional
 
-from dacite import from_dict, Config
+from dacite import Config, from_dict
 
-from roborock.code_mappings import RoborockDockWashTowelModeCode, RoborockDockTypeCode, RoborockMopIntensityCode, \
-    RoborockStateCode
-from .code_mappings import RoborockMopModeCode, RoborockDockErrorCode, \
-    RoborockErrorCode, RoborockDockDustCollectionModeCode, RoborockFanPowerCode
+from roborock.code_mappings import (
+    RoborockDockTypeCode,
+    RoborockDockWashTowelModeCode,
+    RoborockMopIntensityCode,
+    RoborockStateCode,
+)
+
+from .code_mappings import (
+    RoborockDockDustCollectionModeCode,
+    RoborockDockErrorCode,
+    RoborockErrorCode,
+    RoborockFanPowerCode,
+    RoborockMopModeCode,
+)
 
 
 def camelize(s: str):
-    first, *others = s.split('_')
-    return ''.join([first.lower(), *map(str.title, others)])
+    first, *others = s.split("_")
+    return "".join([first.lower(), *map(str.title, others)])
 
 
 def decamelize(s: str):
-    return re.sub('([A-Z]+)', '_\\1', s).lower()
+    return re.sub("([A-Z]+)", "_\\1", s).lower()
 
 
 def decamelize_obj(d: dict | list):
@@ -30,15 +40,15 @@ def decamelize_obj(d: dict | list):
 
 @dataclass
 class RoborockBase:
-
     @classmethod
-    def from_dict(cls, data: dict[str, any]):
+    def from_dict(cls, data: dict[str, Any]):
         return from_dict(cls, decamelize_obj(data), config=Config(cast=[Enum]))
 
     def as_dict(self):
-        return asdict(self, dict_factory=lambda _fields: {
-            camelize(key): value for (key, value) in _fields if value is not None
-        })
+        return asdict(
+            self,
+            dict_factory=lambda _fields: {camelize(key): value for (key, value) in _fields if value is not None},
+        )
 
 
 @dataclass
@@ -51,11 +61,11 @@ class Reference(RoborockBase):
 
 @dataclass
 class RRiot(RoborockBase):
-    u: Optional[str] = None
-    s: Optional[str] = None
-    h: Optional[str] = None
-    k: Optional[str] = None
-    r: Optional[Reference] = None
+    u: str
+    s: str
+    h: str
+    k: str
+    r: Reference
 
 
 @dataclass
@@ -169,11 +179,11 @@ class LoginData(RoborockBase):
 class Status(RoborockBase):
     msg_ver: Optional[int] = None
     msg_seq: Optional[int] = None
-    state: Optional[RoborockStateCode] = None
+    state: Optional[RoborockStateCode] = None  # type: ignore[valid-type]
     battery: Optional[int] = None
     clean_time: Optional[int] = None
     clean_area: Optional[int] = None
-    error_code: Optional[RoborockErrorCode] = None
+    error_code: Optional[RoborockErrorCode] = None  # type: ignore[valid-type]
     map_present: Optional[int] = None
     in_cleaning: Optional[int] = None
     in_returning: Optional[int] = None
@@ -183,12 +193,12 @@ class Status(RoborockBase):
     back_type: Optional[int] = None
     wash_phase: Optional[int] = None
     wash_ready: Optional[int] = None
-    fan_power: Optional[RoborockFanPowerCode] = None
+    fan_power: Optional[RoborockFanPowerCode] = None  # type: ignore[valid-type]
     dnd_enabled: Optional[int] = None
     map_status: Optional[int] = None
     is_locating: Optional[int] = None
     lock_status: Optional[int] = None
-    water_box_mode: Optional[RoborockMopIntensityCode] = None
+    water_box_mode: Optional[RoborockMopIntensityCode] = None  # type: ignore[valid-type]
     mop_intensity: Optional[str] = None
     water_box_carriage_status: Optional[int] = None
     mop_forbidden_enable: Optional[int] = None
@@ -198,15 +208,15 @@ class Status(RoborockBase):
     home_sec_enable_password: Optional[int] = None
     adbumper_status: Optional[list[int]] = None
     water_shortage_status: Optional[int] = None
-    dock_type: Optional[RoborockDockTypeCode] = None
+    dock_type: Optional[RoborockDockTypeCode] = None  # type: ignore[valid-type]
     dust_collection_status: Optional[int] = None
     auto_dust_collection: Optional[int] = None
     avoid_count: Optional[int] = None
-    mop_mode: Optional[RoborockMopModeCode] = None
+    mop_mode: Optional[RoborockMopModeCode] = None  # type: ignore[valid-type]
     debug_mode: Optional[int] = None
     collision_avoid_status: Optional[int] = None
     switch_map_mode: Optional[int] = None
-    dock_error_status: Optional[RoborockDockErrorCode] = None
+    dock_error_status: Optional[RoborockDockErrorCode] = None  # type: ignore[valid-type]
     charge_status: Optional[int] = None
     unsave_map_reason: Optional[int] = None
     unsave_map_flag: Optional[int] = None
@@ -290,12 +300,12 @@ class SmartWashParams(RoborockBase):
 
 @dataclass
 class DustCollectionMode(RoborockBase):
-    mode: Optional[RoborockDockDustCollectionModeCode] = None
+    mode: Optional[RoborockDockDustCollectionModeCode] = None  # type: ignore[valid-type]
 
 
 @dataclass
 class WashTowelMode(RoborockBase):
-    wash_mode: Optional[RoborockDockWashTowelModeCode] = None
+    wash_mode: Optional[RoborockDockWashTowelModeCode] = None  # type: ignore[valid-type]
 
 
 @dataclass
